+++
title = "Overriding menu properties completely"
date = 2017-07-18
tags = ["menu"]
draft = false
[menu.test]
  identifier = "overriding-menu-properties-completely"
  weight = 50
+++

For this post, we see that no menu properties are inherited from the
parent; only the menu properties set in his subtree are effective.
